import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)
from loguru import logger
from mns_common.db.MongodbUtil import MongodbUtil
mongodb_util = MongodbUtil('27017')

def create_db_index(str_day):
    query_trade_day = {'_id': str_day}
    is_trade_day = mongodb_util.exist_data_query('trade_date_list', query_trade_day)
    if is_trade_day:
        try:
            mongodb_util.create_index('realtime_quotes_now_' + str_day, [("symbol", 1)])
            mongodb_util.create_index('realtime_quotes_now_' + str_day, [("number", 1)])
            mongodb_util.create_index('realtime_quotes_now_' + str_day, [("symbol", 1), ("number", 1)])
            mongodb_util.create_index('realtime_quotes_now_' + str_day, [("str_now_date", 1)])
            logger.info("创建索引成功:{}", str_day)
        except BaseException:
            logger.warning("创建索引异常:{}", )


if __name__ == '__main__':
    create_db_index("2023-08-11")



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)
import mns_common.component.concept.ths_concept_common_service_api as ths_concept_common_service_api
import mns_common.component.common_service_fun_api as common_service_fun_api
import mns_common.api.ths.concept.app.ths_concept_detail_app as ths_concept_detail_app
import mns_common.api.ths.wen_cai.ths_wen_cai_api as ths_wen_cai_api
import mns_common.api.em.east_money_stock_api as east_money_stock_api
import mns_common.component.company.company_common_service_new_api as company_common_service_new_api
import mns_common.api.ths.concept.web.ths_concept_detail_web as ths_concept_detail_web
import math
from loguru import logger
import pandas as pd
import mns_common.utils.data_frame_util as data_frame_util


def get_ths_concept_detail(concept_code, concept_name):
    real_time_quotes_all_stocks = east_money_stock_api.get_real_time_quotes_all_stocks()
    # 1  通过入选理获取概念组成股票详情
    ths_concept_detail_by_explain = get_ths_concept_detail_by_explain(concept_code, real_time_quotes_all_stocks)
    # 2 app 分享链接获取概念组成详情
    ths_concept_detail_from_app = get_ths_concept_detail_from_app(concept_code, real_time_quotes_all_stocks)
    # 3 通过问财
    if concept_name is None or data_frame_util.is_string_empty(concept_name):
        ths_concept_list = ths_concept_common_service_api.get_all_ths_concept()
        ths_concept_one_df = ths_concept_list.loc[
            (ths_concept_list['symbol'] == int(concept_code))
            | (ths_concept_list['web_concept_code'] == int(concept_code))]
        if data_frame_util.is_not_empty(ths_concept_one_df):
            concept_name = list(ths_concept_one_df['name'])[0]
    if data_frame_util.is_string_not_empty(concept_name) and concept_name is not None:
        concept_detail_by_wen_cai_df = get_ths_concept_detail_by_wen_cai(concept_name, real_time_quotes_all_stocks)
    else:
        concept_detail_by_wen_cai_df = None
    # 4 通过web端
    ths_concept_detail_from_web_df = get_ths_concept_detail_from_web(concept_code, real_time_quotes_all_stocks)
    # 判断是否都为空
    all_are_none = all(
        df is None for df in [ths_concept_detail_by_explain, ths_concept_detail_from_app,
                              concept_detail_by_wen_cai_df, ths_concept_detail_from_web_df])
    if all_are_none:
        return None
    result_df = pd.concat([ths_concept_detail_by_explain, ths_concept_detail_from_app,
                           concept_detail_by_wen_cai_df, ths_concept_detail_from_web_df])

    result_df.drop_duplicates('symbol', keep='last', inplace=True)
    if data_frame_util.is_not_empty(ths_concept_detail_by_explain):
        ths_concept_detail_by_explain_new = ths_concept_detail_by_explain.loc[
            ths_concept_detail_by_explain['symbol'].isin(result_df['symbol'])]

        not_in_ths_concept_detail_by_explain = result_df.loc[~(
            result_df['symbol'].isin(ths_concept_detail_by_explain['symbol']))]
        result_df = pd.concat([ths_concept_detail_by_explain_new, not_in_ths_concept_detail_by_explain])
    return result_df


# 通过入选理获取概念组成股票详情
def get_ths_concept_detail_by_explain(concept_code, real_time_quotes_all_stocks):
    page_size = 800

    de_list_symbols = company_common_service_new_api.get_de_list_company()
    real_time_quotes_all_stocks = real_time_quotes_all_stocks.loc[
        ~(real_time_quotes_all_stocks['symbol'].isin(de_list_symbols))]

    max_page_number = math.ceil(real_time_quotes_all_stocks.shape[0] / page_size)
    page = 0

    result_df = None

    while page < max_page_number:
        try:

            begin_index = page * page_size
            end_index = (page + 1) * page_size
            page_df = real_time_quotes_all_stocks.iloc[begin_index: end_index]
            code_list = ','.join(page_df['symbol'].astype(str))
            all_ths_concept_detail = ths_concept_detail_app.get_concept_explain(concept_code, code_list)
            if data_frame_util.is_empty(result_df) and data_frame_util.is_not_empty(all_ths_concept_detail):
                result_df = all_ths_concept_detail
            elif data_frame_util.is_not_empty(result_df) and data_frame_util.is_not_empty(all_ths_concept_detail):
                result_df = pd.concat([all_ths_concept_detail, result_df])
        except BaseException as e:
            logger.error("通过ths概念入选理由列表获取详情异常:{},{}", concept_code, e)
        page = page + 1
    if data_frame_util.is_not_empty(result_df):
        result_df = result_df[result_df['explain'].astype(str).str.len() > 0]
    if data_frame_util.is_not_empty(result_df):
        result_df = result_df.rename(columns={
            "stockCode": "symbol",
            "explain": "long"})
        result_df = merge_data_common_fun(result_df, real_time_quotes_all_stocks)
        return result_df
    else:
        return None


# 通过分享链接获取
def get_ths_concept_detail_from_app(concept_code, real_time_quotes_all_stocks):
    ths_concept_detail_from_app = ths_concept_detail_app.get_ths_concept_detail_by_app(concept_code)
    if data_frame_util.is_not_empty(ths_concept_detail_from_app):
        ths_concept_detail_from_app['long'] = ''
        ths_concept_detail_from_app = ths_concept_detail_from_app[[
            'symbol',
            'long'
        ]]
        ths_concept_detail_from_app = merge_data_common_fun(ths_concept_detail_from_app,
                                                            real_time_quotes_all_stocks)
        return ths_concept_detail_from_app

    else:
        return None


# 3 通过问财
def get_ths_concept_detail_by_wen_cai(concept_name, real_time_quotes_all_stocks):
    concept_detail_by_wen_cai_df = ths_wen_cai_api.get_concept_detail_by_wen_cai(concept_name)
    if data_frame_util.is_not_empty(concept_detail_by_wen_cai_df):
        concept_detail_by_wen_cai_df = concept_detail_by_wen_cai_df[[
            'symbol',
            'explain'
        ]]

        concept_detail_by_wen_cai_df = concept_detail_by_wen_cai_df.rename(columns={
            "explain": "long"})
        concept_detail_by_wen_cai_df = merge_data_common_fun(concept_detail_by_wen_cai_df,
                                                             real_time_quotes_all_stocks)

    return concept_detail_by_wen_cai_df


# 通过web端 最近不可用
def get_ths_concept_detail_from_web(concept_code, real_time_quotes_all_stocks):
    ths_concept_detail_from_web_df = ths_concept_detail_web.stock_board_cons_ths(concept_code)
    if data_frame_util.is_not_empty(ths_concept_detail_from_web_df):
        ths_concept_detail_from_web_df = ths_concept_detail_from_web_df[[
            'symbol'
        ]]
        ths_concept_detail_from_web_df['long'] = ''

        ths_concept_detail_from_web_df = merge_data_common_fun(ths_concept_detail_from_web_df,
                                                               real_time_quotes_all_stocks)

    return ths_concept_detail_from_web_df


def merge_data_common_fun(result_df, real_time_quotes_all_stocks):
    real_time_quotes_ths_detail = real_time_quotes_all_stocks.loc[
        real_time_quotes_all_stocks['symbol'].isin(result_df['symbol'])]
    real_time_quotes_ths_detail = common_service_fun_api.total_mv_classification(real_time_quotes_ths_detail)
    real_time_quotes_ths_detail = real_time_quotes_ths_detail[[
        "symbol",
        "name",
        "now_price",
        "chg",
        "exchange",
        "amount",
        "flow_mv_sp",
        "total_mv_sp"]]

    query_field = {
        "concept_name": 1,
        "concept_code": 1,
        "company_type": 1,
        "concept_create_day": 1,
        "first_relevance_industry": 1,
        "second_relevance_industry": 1,
        "industry": 1
    }
    query_field_key = str(query_field)
    query_key = str({})
    company_df = company_common_service_new_api.get_company_info_by_field(query_key, query_field_key)
    company_ths_df = company_df.loc[company_df['_id'].isin(result_df['symbol'])]

    result_df['short'] = result_df['long']
    result_df = result_df.set_index(['symbol'], drop=True)
    company_ths_df = company_ths_df.set_index(['_id'], drop=True)
    real_time_quotes_ths_detail = real_time_quotes_ths_detail.set_index(['symbol'], drop=False)
    result_df = pd.merge(real_time_quotes_ths_detail, result_df,
                         how='outer',
                         left_index=True, right_index=True)
    result_df = pd.merge(result_df, company_ths_df,
                         how='outer',
                         left_index=True, right_index=True)
    return result_df


if __name__ == '__main__':
    get_ths_concept_detail('886073', '铜缆高速连接')
    real_time_quotes_all_stocks_df = east_money_stock_api.get_real_time_quotes_all_stocks()
    get_ths_concept_detail_from_web('886072', real_time_quotes_all_stocks_df)
    get_ths_concept_detail_by_explain('886078', real_time_quotes_all_stocks_df)
    get_ths_concept_detail_by_wen_cai('PCB概念', real_time_quotes_all_stocks_df)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)
from mns_common.db.MongodbUtil import MongodbUtil
import pandas as pd
import mns_scheduler.concept.common.detaill.ths_concept_detail_api as ths_concept_detail_api
import time
from loguru import logger
import mns_common.component.company.company_common_service_api as company_common_service_api
import mns_common.constant.db_name_constant as db_name_constant

mongodb_util = MongodbUtil('27017')


# 统计概念股票数量和行业分组信息
def update_ths_concept_info():
    ths_concept_list = mongodb_util.find_all_data(db_name_constant.THS_CONCEPT_LIST)
    for ths_concept_one in ths_concept_list.itertuples():
        try:
            query = {'concept_code': ths_concept_one.symbol}
            ths_stock_concept_detail_df = (mongodb_util
                                           .find_query_data(db_name_constant.THS_STOCK_CONCEPT_DETAIL, query))
            concept_count = ths_stock_concept_detail_df.shape[0]
            ths_concept_list_one_df = ths_concept_list.loc[ths_concept_list['symbol'] == ths_concept_one.symbol]
            ths_concept_list_one_df['concept_count'] = concept_count

            ths_stock_concept_detail_df = ths_stock_concept_detail_df.reset_index(drop=True)
            if 'industry' in ths_stock_concept_detail_df.columns:
                del ths_stock_concept_detail_df['industry']

            company_info_df = company_common_service_api.get_company_info_industry()
            company_info_df = company_info_df[['_id', 'industry']]
            company_info_df = company_info_df.loc[
                company_info_df['_id'].isin(list(ths_stock_concept_detail_df['symbol']))]
            company_info_df = company_info_df.set_index(['_id'], drop=True)

            ths_stock_concept_detail_df = ths_stock_concept_detail_df.set_index(['symbol'], drop=False)
            ths_stock_concept_detail_df = pd.merge(ths_stock_concept_detail_df, company_info_df,
                                                   how='outer',
                                                   left_index=True, right_index=True)
            ths_stock_concept_detail_df.dropna(subset=['industry'], axis=0, inplace=True)

            grouped = ths_stock_concept_detail_df.groupby('industry')
            result_list = grouped.size()
            ths_concept_group = pd.DataFrame(result_list, columns=['number'])
            ths_concept_group['industry'] = ths_concept_group.index
            ths_concept_group = ths_concept_group.sort_values(by=['number'], ascending=False)
            if ths_concept_group.shape[0] >= 2:
                first_relevance_industry = list(ths_concept_group.iloc[0:1]['industry'])[0]
                first_relevance_industry_number = list(ths_concept_group.iloc[0:1]['number'])[0]
                second_relevance_industry = list(ths_concept_group.iloc[1:2]['industry'])[0]
                second_relevance_industry_number = list(ths_concept_group.iloc[1:2]['number'])[0]
            else:
                first_relevance_industry = list(ths_concept_group.iloc[0:1]['industry'])[0]
                first_relevance_industry_number = list(ths_concept_group.iloc[0:1]['number'])[0]
                second_relevance_industry = '无'
                second_relevance_industry_number = 0
            ths_concept_list_one_df['first_relevance_industry'] = first_relevance_industry
            ths_concept_list_one_df['second_relevance_industry'] = second_relevance_industry
            ths_concept_list_one_df['first_relevance_industry_number'] = first_relevance_industry_number
            ths_concept_list_one_df['second_relevance_industry_number'] = second_relevance_industry_number

            ths_stock_concept_detail_df['first_relevance_industry'] = first_relevance_industry
            ths_stock_concept_detail_df['second_relevance_industry'] = second_relevance_industry

            mongodb_util.save_mongo(ths_concept_list_one_df, db_name_constant.THS_CONCEPT_LIST)
            mongodb_util.save_mongo(ths_stock_concept_detail_df, db_name_constant.THS_STOCK_CONCEPT_DETAIL)

        except BaseException as e:
            logger.error("更新概念信息异常:{},{}", e, ths_concept_one.name)


# 更新空名字
def update_null_name():
    query = {"_id": {'$gte': 886025}}
    ths_concept_list = mongodb_util.find_query_data('ths_concept_list', query)
    ths_concept_list = ths_concept_list.sort_values(by=['_id'], ascending=False)

    for concept_one in ths_concept_list.itertuples():
        concept_code = concept_one.symbol
        name = concept_one.name
        exist_url = concept_one.url

        if name == '':
            concept_name = ths_concept_detail_api.get_ths_concept_detail(concept_code, None)
            query_concept = {"symbol": concept_code}
            new_values = {'$set': {"name": concept_name}}
            mongodb_util.update_one_query(query_concept, new_values, 'ths_concept_list')

            new_values_detail = {'$set': {"concept_name": concept_name}}

            query_concept_detail = {"concept_code": concept_code}

            mongodb_util.update_many(query_concept_detail, new_values_detail, 'ths_stock_concept_detail')
            time.sleep(10)

        if exist_url == '' or pd.isna(exist_url):
            url = 'http://q.10jqka.com.cn/thshy/detail/code/' + str(concept_code)
            str_now_time = concept_one.str_day + " " + "00:00:00"
            query_concept = {"symbol": concept_code}
            new_values = {'$set': {"url": url, "str_now_time": str_now_time}}
            mongodb_util.update_one_query(query_concept, new_values, 'ths_concept_list')


if __name__ == '__main__':
    logger.info("开始")
    update_ths_concept_info()
    logger.info("结束")
    update_null_name()



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)

import mns_scheduler.concept.common.detaill.ths_concept_detail_api as ths_concept_detail_api
import mns_common.component.self_choose.black_list_service_api as black_list_service_api
from datetime import datetime
from loguru import logger
import mns_common.utils.data_frame_util as data_frame_util
from mns_common.constant.black_list_classify_enum import BlackClassify


def add_concept_to_lack_list(concept_code, reason):
    new_concept_symbol_list = ths_concept_detail_api.get_ths_concept_detail(concept_code, None)
    if data_frame_util.is_empty(new_concept_symbol_list):
        return None

    now_date = datetime.now()
    str_now_day = now_date.strftime('%Y-%m-%d')
    str_now_date = now_date.strftime('%Y-%m-%d %H:%M:%S')
    for stock_one in new_concept_symbol_list.itertuples():
        try:
            symbol = stock_one.symbol
            key_id = str(concept_code) + "_" + symbol
            black_list_service_api.save_black_stock(
                key_id,
                symbol,
                stock_one.name,
                str_now_day,
                str_now_date,
                reason,
                reason,
                '',
                BlackClassify.SELF_SHIELD_OTHER.up_level_code,
                BlackClassify.SELF_SHIELD_OTHER.up_level_name,
                BlackClassify.SELF_SHIELD_OTHER.level_code,
                BlackClassify.SELF_SHIELD_OTHER.level_name,

            )
        except BaseException as e:
            logger.error("概念拉黑异常:{}", e)


# 微盘股拉黑
if __name__ == '__main__':
    reason_detail = '微盘股拉黑'
    concept_code_wei_pan = '883418'
    add_concept_to_lack_list(concept_code_wei_pan, reason_detail)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)
import mns_scheduler.real_time.realtime_quotes_now_sync as realtime_quotes_now_sync
import mns_scheduler.company_info.clean.company_info_clean_api as company_info_clean_api
from loguru import logger
from apscheduler.schedulers.blocking import BlockingScheduler


def sync_realtime_quotes():
    logger.error("同步实时数据开始")
    # 更新新股公司信息
    company_info_clean_api.new_company_info_update()
    realtime_quotes_now_sync.sync_realtime_quotes()
    logger.error("同步实时数据完成")


blockingScheduler = BlockingScheduler()

# 同步实时数据
blockingScheduler.add_job(sync_realtime_quotes, 'cron', hour='09', minute='20', max_instances=4)

print('同步实时行情定时任务启动成功')
blockingScheduler.start()



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)

import time
import datetime
from mns_common.db.MongodbUtil import MongodbUtil
import mns_scheduler.concept.ths.common.ths_concept_sync_common_api as ths_concept_sync_common_api

mongodb_util = MongodbUtil('27017')


# 通过概念指数同步所有概念下的股票组成

# 同步概念下所有股票组成
def update_concept_all_detail_info():
    query = {"symbol": {'$exists': True}}
    new_concept_list = mongodb_util.find_query_data("ths_concept_list", query)
    new_concept_list = new_concept_list.sort_values(by=['symbol'], ascending=False)
    if new_concept_list.shape[0] > 0:
        for one_concept in new_concept_list.itertuples():
            now_date_time = datetime.datetime.now()
            str_day = now_date_time.strftime('%Y-%m-%d')
            str_now_time = now_date_time.strftime('%Y-%m-%d %H:%M:%S')
            new_concept_symbol_df = ths_concept_sync_common_api.get_concept_detail_info_web(one_concept.symbol)

            if new_concept_symbol_df is None or new_concept_symbol_df.shape[0] == 0:
                time.sleep(10)
                continue
            time.sleep(1)
            new_concept_symbol_df.loc[:, 'way'] = 'index_sync'
            ths_concept_sync_common_api.save_ths_concept_detail(new_concept_symbol_df, one_concept.name,
                                                                str_day, str_now_time, one_concept.symbol)


if __name__ == '__main__':
    now_date = datetime.datetime.now()
    begin_date = now_date.strftime('%Y-%m-%d %H:%M:%S')
    print('同步开始:' + begin_date)
    update_concept_all_symbol_detail()
    now_date = datetime.datetime.now()
    end_date = now_date.strftime('%Y-%m-%d %H:%M:%S')
    print('同步结束:' + end_date)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.utils.date_handle_util as date_handle_util
from mns_common.component.classify.symbol_classify_param import stock_type_classify_param

mongodb_util = MongodbUtil('27017')


# 处理月线 周线 todo 暂时简单计算周线之和
def handle_month_week_line(k_line_info, str_day, symbol, deal_days):
    sub_stock_new_max_deal_days = stock_type_classify_param['sub_stock_new_max_deal_days']
    if deal_days > sub_stock_new_max_deal_days:
        k_line_info = handle_month_line(k_line_info, str_day, symbol)
        k_line_info = handle_week_line(k_line_info, str_day, symbol)
    else:
        k_line_info['week01'] = 0
        k_line_info['week02'] = 0
        k_line_info['week03'] = 0
        k_line_info['week04'] = 0
        k_line_info['sum_week'] = 0
        k_line_info['week_num'] = 0
        k_line_info['week_last_day'] = '19890729'

        k_line_info['sum_month'] = 0
        k_line_info['month_num'] = 0
        k_line_info['month01'] = 0
        k_line_info['month02'] = 0
        k_line_info['month01_date'] = '19890729'
        k_line_info['month02_date'] = '19890729'
    return k_line_info


# 处理月线
def handle_month_line(k_line_info, str_day, symbol):
    month_begin_day = str_day[0:7] + '-01'
    query = {"symbol": symbol,
             'date': {"$lt": date_handle_util.no_slash_date(month_begin_day)}}
    stock_hfq_monthly = mongodb_util.descend_query(query, 'stock_qfq_monthly', 'date', 2)
    month_num = stock_hfq_monthly.shape[0]
    k_line_info['month_num'] = month_num
    if month_num > 0:
        k_line_info['sum_month'] = round(sum(stock_hfq_monthly['chg']), 2)
    else:
        k_line_info['sum_month'] = 0

    if month_num == 0:
        k_line_info['month01'] = 0
        k_line_info['month02'] = 0
        k_line_info['month01_date'] = '19890729'
        k_line_info['month02_date'] = '19890729'
    elif month_num == 1:
        k_line_info['month01'] = stock_hfq_monthly.iloc[0].chg
        k_line_info['month02'] = 0
        k_line_info['month01_date'] = stock_hfq_monthly.iloc[0].date
        k_line_info['month02_date'] = '19890729'
    elif month_num == 2:
        k_line_info['month01'] = stock_hfq_monthly.iloc[0].chg
        k_line_info['month02'] = stock_hfq_monthly.iloc[1].chg
        k_line_info['month01_date'] = stock_hfq_monthly.iloc[0].date
        k_line_info['month02_date'] = stock_hfq_monthly.iloc[1].date

    return k_line_info


# 处理周线
def handle_week_line(k_line_info, str_day, symbol):
    month_begin_day = str_day[0:7] + '-01'
    query = {"symbol": symbol,
             '$and': [{'date': {"$gte": date_handle_util.no_slash_date(month_begin_day)}},
                      {'date': {"$lt": date_handle_util.no_slash_date(str_day)}}]}
    stock_hfq_weekly = mongodb_util.find_query_data('stock_qfq_weekly', query)
    week_num = stock_hfq_weekly.shape[0]
    if week_num > 0:
        stock_hfq_weekly = stock_hfq_weekly.sort_values(by=['date'], ascending=False)
        k_line_info['sum_week'] = round(sum(stock_hfq_weekly['chg']), 2)
    else:
        k_line_info['sum_week'] = 0
    k_line_info['week_num'] = week_num
    if week_num == 1:
        k_line_info['week01'] = stock_hfq_weekly.iloc[0].chg
        k_line_info['week02'] = 0
        k_line_info['week03'] = 0
        k_line_info['week04'] = 0
    elif week_num == 2:
        k_line_info['week01'] = stock_hfq_weekly.iloc[0].chg
        k_line_info['week02'] = stock_hfq_weekly.iloc[1].chg
        k_line_info['week03'] = 0
        k_line_info['week04'] = 0
    elif week_num == 3:
        k_line_info['week01'] = stock_hfq_weekly.iloc[0].chg
        k_line_info['week02'] = stock_hfq_weekly.iloc[1].chg
        k_line_info['week03'] = stock_hfq_weekly.iloc[2].chg
        k_line_info['week04'] = 0
    elif week_num >= 4:
        k_line_info['week01'] = stock_hfq_weekly.iloc[0].chg
        k_line_info['week02'] = stock_hfq_weekly.iloc[1].chg
        k_line_info['week03'] = stock_hfq_weekly.iloc[2].chg
        k_line_info['week04'] = stock_hfq_weekly.iloc[3].chg
    elif week_num == 0:
        k_line_info['week01'] = 0
        k_line_info['week02'] = 0
        k_line_info['week03'] = 0
        k_line_info['week04'] = 0
        k_line_info['week_last_day'] = month_begin_day
        k_line_info['sum_week'] = 0
        return k_line_info
    stock_hfq_weekly = stock_hfq_weekly.sort_values(by=['date'], ascending=False)
    stock_hfq_weekly_last = stock_hfq_weekly.iloc[0:1]
    k_line_info['week_last_day'] = list(stock_hfq_weekly_last['date'])[0]

    return k_line_info



from datetime import datetime
import mns_common.component.self_choose.black_list_service_api as black_list_service_api
import mns_common.constant.db_name_constant as db_name_constant
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.component.common_service_fun_api as common_service_fun_api
from mns_common.constant.black_list_classify_enum import BlackClassify

mongodb_util = MongodbUtil('27017')
# 最大负债比
MAX_LIABILITY_RATIO = 90
# 最小净资产1.5亿
MIN_NET_ASSET = 150000000
# 排除校验负债比的行业
EXCLUDE_INDUSTRY = ['保险', '银行', '证券']


# 负债比校验| 净资产check
def net_assets_check(report_type, new_report_df, period_time):
    if report_type == db_name_constant.EM_STOCK_ASSET_LIABILITY:
        new_report_df = new_report_df.sort_values(by=['REPORT_DATE'], ascending=False)
        new_report_one_df = new_report_df.iloc[0:1]
        # 负债比
        liability_ratio = round(
            list(new_report_one_df['TOTAL_LIABILITIES'])[0] * 100 / list(new_report_one_df['TOTAL_ASSETS'])[0],
            2)
        # 净资产
        net_asset = round(list(new_report_one_df['TOTAL_ASSETS'])[0] - list(new_report_one_df['TOTAL_LIABILITIES'])[0],
                          2)

        symbol = list(new_report_one_df['SECURITY_CODE'])[0]
        name = list(new_report_one_df['SECURITY_NAME_ABBR'])[0]
        now_date = datetime.now()
        str_day = now_date.strftime('%Y-%m-%d')
        str_now_date = now_date.strftime('%Y-%m-%d %H:%M:%S')
        id_key = symbol + "_" + period_time + "_" + BlackClassify.FINANCIAL_PROBLEM_DEBT.level_code
        notice_date = list(new_report_one_df['NOTICE_DATE'])[0]
        query_company = {'_id': symbol, 'industry': {'$in': EXCLUDE_INDUSTRY}}
        if mongodb_util.exist_data_query(db_name_constant.COMPANY_INFO, query_company):
            return None

        if liability_ratio >= MAX_LIABILITY_RATIO:
            black_list_service_api.save_black_stock(id_key,
                                                    symbol,
                                                    name,
                                                    str_day,
                                                    notice_date,
                                                    '负债过高:' + "[" + "负债比:" + str(
                                                        liability_ratio) + "]" + "," + "净资产:"
                                                    + str(round(net_asset / common_service_fun_api.HUNDRED_MILLION,
                                                                0)) + "亿",
                                                    '负债过高:' + "[" + str(liability_ratio) + "]",
                                                    '',
                                                    BlackClassify.FINANCIAL_PROBLEM_DEBT.up_level_code,
                                                    BlackClassify.FINANCIAL_PROBLEM_DEBT.up_level_name,
                                                    BlackClassify.FINANCIAL_PROBLEM_DEBT.level_code,
                                                    BlackClassify.FINANCIAL_PROBLEM_DEBT.level_name)
        if net_asset < MIN_NET_ASSET:
            black_list_service_api.save_black_stock(id_key,
                                                    symbol,
                                                    name,
                                                    str_day,
                                                    notice_date,
                                                    '净资产低:' + "[" + "负债比:" + str(
                                                        liability_ratio) + "]" + "," + "净资产:"
                                                    + str(round(net_asset / common_service_fun_api.HUNDRED_MILLION,
                                                                0)) + "亿",
                                                    '净资产低:' + "[" + str(liability_ratio) + "]",
                                                    '',
                                                    BlackClassify.FINANCIAL_PROBLEM_DEBT.up_level_code,
                                                    BlackClassify.FINANCIAL_PROBLEM_DEBT.up_level_name,
                                                    BlackClassify.FINANCIAL_PROBLEM_DEBT.level_code,
                                                    BlackClassify.FINANCIAL_PROBLEM_DEBT.level_name)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)

import sys
import os

from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.constant.db_name_constant as db_name_constant
import threading
import pandas as pd
import mns_common.api.kpl.common.kpl_common_api as kpl_common_api
import mns_common.utils.data_frame_util as data_frame_util

KPL_MINUTE_LIST = ['0930', '0935', '0940', '0945', '0950', '0955',
                   '1000', '1005', '1010', '1015', '1020', '1025',
                   '1030', '1035', '1040', '1045', '1050', '1055',
                   '1100', '1105', '1110', '1115', '1120', '1125',
                   '1130',
                   '1305', '1310', '1315', '1320', '1325',
                   '1330', '1335', '1340', '1345', '1350', '1355',
                   '1400', '1405', '1410', '1415', '1420', '1425',
                   '1430', '1435', '1440', '1445', '1450', '1455',
                   '1500']

KPL_MINUTE_BEGIN = "0925"
KPL_MINUTE_END = "1500"
file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)

mongodb_util = MongodbUtil('27017')
# 定义一个全局锁，用于保护 result 变量的访问
result_lock = threading.Lock()
# 初始化 result 变量为一个空的 Pandas DataFrame
result = pd.DataFrame()


def sync_best_choose_his_index(str_day):
    all_kpl_best_choose_index_df = kpl_common_api \
        .get_plate_index(kpl_common_api.BEST_CHOOSE)
    kpl_best_choose_index_number = all_kpl_best_choose_index_df.shape[0]
    page_max_number = kpl_best_choose_index_number / kpl_common_api.HIS_PAGE_MAX_COUNT
    page_number = 0
    number = 1
    for end_time in KPL_MINUTE_LIST:
        while page_number <= page_max_number:
            index = page_number * kpl_common_api.HIS_PAGE_MAX_COUNT
            kpl_plate_best_index_df = kpl_common_api.get_plate_index_his(index, kpl_common_api.BEST_CHOOSE,
                                                                         str_day, KPL_MINUTE_BEGIN,
                                                                         end_time)

            if data_frame_util.is_empty(kpl_plate_best_index_df):
                continue
            kpl_plate_best_index_df['number'] = number
            kpl_plate_best_index_df['str_day'] = str_day
            hour = end_time[0:2]
            minute = end_time[2:4]
            str_now_date = str_day + " " + hour + ":" + minute + ":" + "00"
            kpl_plate_best_index_df['str_now_date'] = str_now_date
            kpl_plate_best_index_df = kpl_plate_best_index_df[[
                "plate_code",
                "plate_name",
                "heat_score",
                "chg",
                "speed",
                "amount",
                "main_net_inflow",
                "main_inflow_in",
                "main_inflow_out",
                "quantity_ratio",
                "flow_mv",
                "super_order_net",
                "total_mv",
                "last_reason_organ_add",
                "ava_pe_now",
                "ava_pe_next",
                "number",
                "str_day",
                "str_now_date"

            ]]
            save_kpl_his_index(kpl_plate_best_index_df, str_day, end_time)
            if end_time == KPL_MINUTE_END:
                save_kpl_his_daily(kpl_plate_best_index_df, str_day, end_time)
            page_number = page_number + 1
        # 执行下一个时间段
        page_number = 0
        number = number + 1


def save_kpl_his_index(kpl_plate_best_index_df, str_day, end_time):
    kpl_plate_best_index_df['_id'] = str_day + '-' + end_time + '-' + kpl_plate_best_index_df['plate_code']
    mongodb_util.save_mongo(kpl_plate_best_index_df, db_name_constant.KPL_BEST_CHOOSE_HIS)


def save_kpl_his_daily(kpl_plate_best_index_df, str_day, end_time):
    kpl_plate_best_index_df['_id'] = str_day + '-' + end_time + '-' + kpl_plate_best_index_df['plate_code']
    mongodb_util.save_mongo(kpl_plate_best_index_df, db_name_constant.KPL_BEST_CHOOSE_DAILY)


def sync_all_days():
    query = {"_id": {"$gte": '2024-04-26'}, 'trade_date': {"$lte": "2024-05-07"}}
    trade_date_list = mongodb_util.find_query_data('trade_date_list', query)
    trade_date_list = trade_date_list.sort_values(by=['trade_date'], ascending=False)
    for trade_one in trade_date_list.itertuples():
        sync_best_choose_his_index(trade_one.trade_date)


if __name__ == '__main__':
    sync_all_days()
    # sync_best_choose_his_index('2024-04-19')
